@@ -6,13 +6,15 @@ import psycopg2
 import itertools
 import psycopg2.extras
 from decimal import Decimal
+from psycopg2.extensions import adapt
 
-__version__ = VERSION = version = '0.2.0'
+__version__ = VERSION = version = '0.2.1'
 
 from .pubsub import PubSub
 
+
 class Connection(object):
-    def __init__(self, host_or_url="127.0.0.1", database=None, user=None, password=None, port=5432, search_path=None):
+    def __init__(self, host_or_url="127.0.0.1", database=None, user=None, password=None, port=5432, search_path=None, timezone="+00"):
         self.logging = False
         if host_or_url.startswith('postgres://'):
             args = re.search('postgres://(?P<user>[\w\-]*):?(?P<password>[\w\-]*)@(?P<host>[\w\-\.]+):?(?P<port>\d+)/?(?P<database>[\w\-]+)', host_or_url).groupdict()
@@ -24,6 +26,7 @@ class Connection(object):
             args = dict(host=host_or_url, database=database, port=int(port), 
                         user=user, password=password)
 
+        self.timezone = timezone
         self._db = None
         self._db_args = args
         self._register_types = []
@@ -66,6 +69,9 @@ class Connection(object):
         self._change_path = search_path
         return self
 
+    def adapt(self, value):
+        return adapt(value)
+
     def hstore(self, dict):
         return ','.join(['"%s"=>"%s"' % (str(k), str(v)) for k, v in dict.items()])
 
@@ -97,11 +103,11 @@ class Connection(object):
             cursor.close()
             raise
 
-    def query(self, query, *parameters):
+    def query(self, query, *parameters, **kwargs):
         """Returns a row list for the given query and parameters."""
         cursor = self._cursor()
         try:
-            self._execute(cursor, query, parameters)    
+            self._execute(cursor, query, parameters, kwargs)    
             if cursor.description:
                 column_names = [column.name for column in cursor.description]
                 return [Row(itertools.izip(column_names, row)) for row in cursor.fetchall()]
@@ -113,9 +119,9 @@ class Connection(object):
         """Alias for query"""
         return self.query(query, *parameters)
 
-    def get(self, query, *parameters):
+    def get(self, query, *parameters, **kwargs):
         """Returns the first row returned for the given query."""
-        rows = self.query(query, *parameters)
+        rows = self.query(query, *parameters, **kwargs)
         if not rows:
             return None
         elif len(rows) > 1:
@@ -134,11 +140,11 @@ class Connection(object):
             cursor.close()
             raise
 
-    def execute_rowcount(self, query, *parameters):
+    def execute_rowcount(self, query, *parameters, **kwargs):
         """Executes the given query, returning the rowcount from the query."""
         cursor = self._cursor()
         try:
-            self._execute(cursor, query, parameters)
+            self._execute(cursor, query, parameters, kwargs)
             return cursor.rowcount
         finally:
             cursor.close()
@@ -151,15 +157,40 @@ class Connection(object):
         self._ensure_connected()
         return self._db.cursor()
 
-    def _execute(self, cursor, query, parameters):
+    def _set_search_path(self, query):
+        if self._change_path and not re.search(r'^set search_path', query, re.I):
+            query = ("set search_path = %s;" % self._change_path) + query
+            self._change_path = None
+        elif self._search_path and not re.search(r'^set search_path', query, re.I):
+            query = ("set search_path = %s;" % self._search_path) + query
+        if self.timezone:
+            query = ("set timezone = '%s';" % self.timezone) + query
+        return query
+
+    def _execute(self, cursor, query, parameters, kwargs):
         try:
-            if self._change_path and not re.search(r'set search_path', query, re.I):
-                query = ("set search_path = %s;" % self._change_path) + query
-                self._change_path = None
-            elif self._search_path and not re.search(r'set search_path', query, re.I):
-                query = ("set search_path = %s;" % self._search_path) + query
+            query = self._set_search_path(query)
+            if kwargs:
+                datas = []
+                keys = []
+                values = []
+                args = []
+                for key in kwargs:
+                    keys.append(key) # for insert
+                    values.append("%s") # for insert
+                    datas.append(key+"=%s") # for update
+                    args.append(kwargs[key])
+                parampos = min([x for x, part in enumerate(query.split("%s")) if part.find('__data__') > -1] or [0])
+                args.reverse()
+                parameters = list(parameters)
+                [parameters.insert(parampos, value) for value in args]
+                query = query.replace("__data__", ','.join(datas))
+                query = query.replace("__keys__", ','.join(keys))
+                query = query.replace("__values__", ','.join(values))
+                parameters = tuple(parameters)
+                
             if self.logging:
-                logging.info(cursor.mogrify(query, parameters))
+                logging.info(re.sub(r"\n\s*", " ", cursor.mogrify(query, parameters)))
             cursor.execute(query, parameters)
         except psycopg2.OperationalError as e:
             logging.error("Error connecting to PostgreSQL on %s, %s", self.host, e)
@@ -169,13 +200,9 @@ class Connection(object):
     def _executemany(self, cursor, query, parameters):
         """The function is mostly useful for commands that update the database: any result set returned by the query is discarded."""
         try:
-            if self._change_path and not re.search(r'set search_path', query, re.I):
-                query = ("set search_path = %s;" % self._change_path) + query
-                self._change_path = None
-            elif self._search_path and not re.search(r'set search_path', query, re.I):
-                query = ("set search_path = %s;" % self._search_path) + query
+            query = self._set_search_path(query)
             if self.logging:
-                logging.info(cursor.mogrify(query, parameters))
+                logging.info(re.sub(r"\n\s*", " ", cursor.mogrify(query, parameters)))
             cursor.executemany(query, parameters)
         except psycopg2.OperationalError as e:
             logging.error("Error connecting to PostgreSQL on %s, e", self.host, e)
@@ -185,17 +212,29 @@ class Connection(object):
     def pubsub(self):
         return PubSub(self._db)
 
-    def file(self, path, execute=True):
+    def file(self, path, _execute=True):
         base = os.path.dirname(path)
         with open(path) as r:
-            sql = re.sub(r'\\ir\s(.*)', lambda m: self.file(os.path.join(base, m.groups()[0]), False), r.read(), re.M)
-        if execute:
+            sql = re.sub(r'\\ir\s(.*)', lambda m: self.file(os.path.join(base, m.groups()[0]), False), r.read())
+        if _execute:
             cursor = self._cursor()
-            cursor.execute(sql)
+            if self._change_path:
+                sql = ("set search_path = %s;" % self._change_path) + sql
+                self._change_path = None
+            elif self._search_path:
+                sql = ("set search_path = %s;" % self._search_path) + sql
+            return cursor.execute(sql)
         else:
             return sql
 
-
+    @property
+    def notices(self):
+        """pops and returns all notices
+        http://initd.org/psycopg/docs/connection.html#connection.notices
+        """
+        if self._db:
+            return [self._db.notices.pop()[8:].strip() for x in range(len(self._db.notices))]
+        return []
 
 class Row(dict):
     """A dict that allows for object-like property access syntax."""
